@@ -3,15 +3,15 @@ use 5.008005;
 use strict;
 use warnings;
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 use Carp qw(croak);
 use Test::Builder::Module;
 our @ISA    = qw(Test::Builder::Module);
 our @EXPORT = qw(subtest before after);
 
-our $Level = 0;
-our $BEFORE = {};
-our $AFTER  = {};
+my $LEVEL  = 0;
+my $BEFORE = {};
+my $AFTER  = {};
 
 BEGIN {
     croak "Test::More::Hooks must be loaded after Test::More."
@@ -20,25 +20,35 @@ BEGIN {
 
 sub subtest {
     my ($name, $subtests) = @_;
-    $BEFORE->{$Level}->() if 'CODE' eq ref $BEFORE->{$Level};
-    $Level += 1;
+    $BEFORE->{$LEVEL}->() if 'CODE' eq ref $BEFORE->{$LEVEL};
+    $LEVEL += 1;
 
     my $tb = Test::More::Hooks->builder;
     my $result = $tb->subtest(@_);
+    _clean_hooks();
 
-    $Level -= 1;
-    $AFTER->{$Level}->() if 'CODE' eq ref $AFTER->{$Level};
+    $LEVEL -= 1;
+    $AFTER->{$LEVEL}->() if 'CODE' eq ref $AFTER->{$LEVEL};
     return $result;
 }
 
 sub before (&) {
     my $block = shift;
-    $BEFORE->{$Level} = $block;
+    $BEFORE->{$LEVEL} = $block;
 }
 
 sub after (&) {
     my $block = shift;
-    $AFTER->{$Level} = $block;
+    $AFTER->{$LEVEL} = $block;
+}
+
+sub level {
+    return $LEVEL;
+}
+
+sub _clean_hooks {
+    $BEFORE->{$LEVEL} = undef;
+    $AFTER->{$LEVEL}  = undef;
 }
 
 1;
